@@ -84,6 +84,7 @@ def send_request(method, end_point, data=None):
 #     raw_data = resp.raw.read()
 #     # Decrypt the response
 
+
 def get_garb(key: str) -> str:
     # Fetch it from API
     resp = send_request("GET", f"/secret/{key}")
@@ -95,5 +96,5 @@ def get_garb(key: str) -> str:
         # if not content:
         #     logger.warning(f"garb: {key} is empty!")
         return content
-    
-    return ''
\ No newline at end of file
+
+    return ""
