@@ -1,5 +1,5 @@
 from decimal import Decimal
-from typing import Union, Literal
+from typing import Union, Literal, List, Optional, Any, Set
 
 from pydantic import Field, model_validator
 
@@ -340,15 +340,16 @@ class AccessKeyRecord(BaseModel):
 class OnPremNodeIn(BaseModel):
     ip: str
     username: str
-    role: VMRole
     ssh_private_key: str
     port: int
     private_ip: Optional[str] = None
+    cpu_only: bool
 
 
 class OnPremNodeDB(OnPremNodeIn):
     id: str
     ssh_key_id: str
+    role: Optional[VMRole] = None
     vcpus: int
     memory: int
     verified: bool
@@ -358,6 +359,26 @@ class OnPremNodeDB(OnPremNodeIn):
     user_id: str
 
 
+class OnPremNodeCandidate(OnPremNodeDB):
+    available_resources: List[str]
+
+
+class OnPremJournalStatus(str, Enum):
+    ACTIVE = "ACTIVE"
+    INACTIVE = "INACTIVE"
+
+
+class OnPremNodeJournal(BaseModel):
+    id: str
+    user_id: str
+    timestamp: str
+    status: OnPremJournalStatus
+    role: VMRole
+    on_prem_node_id: str
+    job_id: str
+    gpu_ids: Set[str]
+
+
 class OnPremNodeEditIn(OnPremNodeIn):
     id: str
 
@@ -369,7 +390,7 @@ class InferenceDeploymentInitialWorkersConfig(BaseModel):
     min_workers: int = 0
     initial_workers_gpu: Optional[GPUType] = None
     initial_workers_gpu_num: Optional[int] = None
-    use_same_gpus_when_scaling: Optional[bool] = False
+    use_other_gpus: Optional[bool] = False
     instance_types: Optional[List[str]] = None
     use_on_prem: Optional[bool] = False
     use_cloudburst: Optional[bool] = False
@@ -377,19 +398,22 @@ class InferenceDeploymentInitialWorkersConfig(BaseModel):
 
 
 class InferenceDeploymentAutoscalingConfig(BaseModel):
-    time_window_sec: Optional[int] = 5*60
-    upper_allowed_latency_sec: Optional[float] = 4
-    lower_allowed_latency_sec: Optional[float] = 1
-    scaling_up_timeout_sec: Optional[int] = 20*60
-    scaling_down_timeout_sec: Optional[int] = 20*60
-    scale_to_zero_timeout_sec: Optional[int] = 30*60
+    scale_up_time_window_sec: Optional[int] = 5 * 60
+    scale_down_time_window_sec: Optional[int] = 5 * 60
+    upper_allowed_latency_sec: Optional[float] = 1
+    lower_allowed_latency_sec: Optional[float] = 0.2
+    scaling_up_timeout_sec: Optional[int] = 20 * 60
+    scaling_down_timeout_sec: Optional[int] = 20 * 60
+    scale_to_zero_timeout_sec: Optional[int] = 30 * 60
     enable_speedup_shared: Optional[bool] = False
+    scale_to_zero: Optional[bool] = False
 
 
-class InferenceDeploymentGatewaycloudChoice(BaseModel):
-    name: ProviderEnum  
+class InferenceDeploymentGatewayCloudChoice(BaseModel):
+    name: ProviderEnum
     region: str
 
+
 class InferenceDeploymentIn(BaseModel):
     name: str
     model: str
@@ -399,7 +423,7 @@ class InferenceDeploymentIn(BaseModel):
     allow_spot_instances: bool = False
     logs_store: Optional[str] = None
     cloud_providers: Optional[List[CloudProviderChoice]] = []
-    gateway_config: Optional[InferenceDeploymentGatewaycloudChoice] = None
+    gateway_config: InferenceDeploymentGatewayCloudChoice
     initial_worker_config: Optional[InferenceDeploymentInitialWorkersConfig] = None
     autoscaling_config: Optional[InferenceDeploymentAutoscalingConfig] = (
         InferenceDeploymentAutoscalingConfig()
@@ -445,10 +469,10 @@ class EstimatedPrice(BaseModel):
 
 class InferenceDeploymentUpdateIn(BaseModel):
     # Initial worker params
-    initial_worker_config: InferenceDeploymentInitialWorkersConfig = None
+    initial_worker_config: Optional[InferenceDeploymentInitialWorkersConfig] = None
 
     # Auto scaling parameters
-    autoscaling_config: InferenceDeploymentAutoscalingConfig = None
+    autoscaling_config: Optional[InferenceDeploymentAutoscalingConfig] = None
     imidiate_scale_down: Optional[bool] = False
 
     max_price_per_hour: Optional[float] = None
@@ -470,6 +494,14 @@ class InferenceDeploymentStatus(str, Enum):
     SCALING = "SCALING"
 
 
+class InferenceDeploymentAPIGatewayData(BaseModel):
+    provider: ProviderEnum
+    api_id: str
+    hash_value: str
+    endpoint: str
+    region: str
+
+
 class InferenceDeploymentDB(InferenceDeploymentIn):
     id: str
     user_id: str
@@ -480,6 +512,8 @@ class InferenceDeploymentDB(InferenceDeploymentIn):
     timestamp: str
     link: Optional[str] = None
     metadata: Optional[dict] = {}
+    api_gateway_data: Optional[InferenceDeploymentAPIGatewayData] = None
+
 
 class InferenceSupportedModelOut(BaseModel):
     model: str
