@@ -103,44 +103,80 @@ code_credentials: Dict[CodeCopyType, List[str]] = {
     CodeCopyType.B2: [],
 }
 
+
 class GPUType(str, Enum):
+    A10G = "A10G"
+    A30 = "A30"
+    A40 = "A40"
     A100 = "A100"
     A100_80GB = "A100_80GB"
+    GH201 = "GH201"
     H100_80GB = "H100_80GB"
-    A10G = "A10G"
-    T4 = "T4"
-    V100 = "V100"
-    RTX_3090 = "RTX_3090"
-    RTX_4090 = "RTX_4090"
-    RTX_A6000 = "RTX_A6000"
-    RTX_A5000 = "RTX_A5000"
-    RTX_A4000 = "RTX_A4000"
-    RTX_6000_ADA = "RTX_6000_ADA"
+    K80 = "K80"
+    L4 = "L4"
     L40 = "L40"
-    A40 = "A40"
-    
-    A30 = "A30"
+    M60 = "M60"
+    P40 = "P40"
+    P100 = "P100"
     RTX_3070 = "RTX_3070"
     RTX_3080 = "RTX_3080"
     RTX_3080_TI = "RTX_3080_TI"
+    RTX_3090 = "RTX_3090"
     RTX_3090_TI = "RTX_3090_TI"
-    RTX_4080 = "RTX_4080"
+    RTX_4000 = "RTX_4000"
     RTX_4070 = "RTX_4070"
     RTX_4070_TI = "RTX_4070_TI"
-    RTX_4000 = "RTX_4000"
+    RTX_4080 = "RTX_4080"
+    RTX_4090 = "RTX_4090"
+    RTX_6000_ADA = "RTX_6000_ADA"
     RTX_A2000 = "RTX_A2000"
+    RTX_A4000 = "RTX_A4000"
     RTX_A4500 = "RTX_A4500"
-    L4 = "L4"
-
-    M60 = "M60"
-    P100 = "P100"
-    K80 = "K80"
-    P40 = "P40"
+    RTX_A5000 = "RTX_A5000"
+    RTX_A6000 = "RTX_A6000"
+    T4 = "T4"
+    V100 = "V100"
     V520 = "V520"
 
     EMPTY = ""
 
 
+on_prem_gpu_type_map = {
+    GPUType.A10G: ["a10"],
+    GPUType.A30: ["a30"],
+    GPUType.A40: ["a40"],
+    GPUType.A100: ["a100", "40gb"],
+    GPUType.A100_80GB: ["a100", "80gb"],
+    GPUType.GH201: ["xxxx"],  # TODO
+    GPUType.H100_80GB: ["h100"],
+    GPUType.K80: ["k80"],
+    GPUType.L4: ["l4"],
+    GPUType.L40: ["l40"],
+    GPUType.M60: ["m60"],
+    GPUType.P40: ["p40"],
+    GPUType.P100: ["p100"],
+    GPUType.RTX_3070: ["3070", "rtx"],
+    GPUType.RTX_3080: ["3080", "rtx"],
+    GPUType.RTX_3080_TI: ["rtx", "3080", "ti"],
+    GPUType.RTX_3090: ["3090", "rtx"],
+    GPUType.RTX_3090_TI: ["rtx", "3090", "ti"],
+    GPUType.RTX_4000: ["rtx", "4000"],
+    GPUType.RTX_4070: ["rtx", "4070"],
+    GPUType.RTX_4070_TI: ["rtx", "4070", "ti"],
+    GPUType.RTX_4080: ["rtx", "4080"],
+    GPUType.RTX_4090: ["rtx", "4090"],
+    GPUType.RTX_6000_ADA: ["rtx", "6000", "ada"],
+    GPUType.RTX_A2000: ["rtx", "a2000"],
+    GPUType.RTX_A4000: ["rtx", "a4000"],
+    GPUType.RTX_A4500: ["rtx", "a4500"],
+    GPUType.RTX_A5000: ["rtx", "a5000"],
+    GPUType.RTX_A6000: ["rtx", "a6000"],
+    GPUType.T4: ["t4"],
+    GPUType.V100: ["v100"],
+    GPUType.V520: ["v520"],
+}
+
+
 # Classes for Config
 class SearchSpaceElement(BaseModel):
     type: str
@@ -406,7 +442,7 @@ class Node(VirtualMachine):
     job_id: str
     user_id: Optional[str] = None
     gpu_count: int = 0
-    gpu_type: Optional[GPUType] = None
+    gpu_type: GPUType = GPUType.EMPTY
     region: str
     timestamp: Optional[str] = None
     spot: bool
@@ -420,6 +456,9 @@ class Node(VirtualMachine):
         if data.get("metadata") is None:
             data["metadata"] = {}
 
+        if data.get("gpu_type") is None:
+            data["gpu_type"] = GPUType.EMPTY.value
+
         super().__init__(**data)
 
 
@@ -472,3 +511,12 @@ class InferenceRecipe(BaseModel):
     gpu_reqs: Dict[GPUType, int]
     is_embeddings: Optional[bool] = False
     type: InferenceDeploymentType
+
+
+class InfPerformanceResult(BaseModel):
+    id: str
+    gpu_type: GPUType
+    llmperf_results: Dict[str, Any]
+    max_model_len: Optional[int] = None
+    num_gpus: int
+    results_mean_output_throughput_token_per_s: float
