@@ -1,5 +1,4 @@
 from typing import Optional
-
 import click
 from rich import box
 from rich.console import Console
@@ -36,19 +35,18 @@ finetune.add_command(launch, name="launch")
 
 @finetune.command(name="create")
 # ******************************* JOB ARGS *******************************
-# @click.option('-e', '--env_var', type=click.STRING, required=False, multiple=True)
-# @click.option("--use_env", is_flag=True)
-# @click.option('-f', '--force', is_flag=True)
 @click.option("-q", "--quiet", is_flag=True, help="Display status updates of workload")
 @click.option(
     "--task",
-    type=click.Choice(["llm", "seq2seq", "text_classification", "token_classification"]),
+    type=click.Choice(
+        ["llm", "seq2seq", "text_classification", "token_classification"]
+    ),
     required=False,
     default="llm",
 )
 @click.option("--job_name", type=click.STRING, required=False)
 @click.option("--artifacts_storage", type=click.STRING, required=False)
-@click.option("--use_spot", is_flag=True, required=False)
+@click.option("--allow_spot_instances", is_flag=True, required=False)
 # ******************************* FINETUNE ARGS *******************************
 @click.option("--model", required=True, type=click.STRING, help="Model to use")
 @click.option(
@@ -154,7 +152,10 @@ finetune.add_command(launch, name="launch")
     help="Block size to use",
 )
 @click.option(
-    "--project_name", required=False, type=click.STRING, help="Project name in Hugging Face hub"
+    "--project_name",
+    required=False,
+    type=click.STRING,
+    help="Project name in Hugging Face hub",
 )
 @click.option(
     "--model_max_length",
@@ -214,7 +215,7 @@ def create(**finetune_kwargs):
 
     # Make request to P-API
     data = {
-        "use_spot": finetune_kwargs["use_spot"],
+        "use_spot": finetune_kwargs["allow_spot_instances"],
         "wandb_key": finetune_kwargs["wandb_key"],
         "model": finetune_kwargs["model"],
         "data_path": finetune_kwargs["data_path"],
@@ -336,8 +337,12 @@ def list(all):
             if all or (
                 not all and (job["status"] == "RUNNING" or job["status"] == "QUEUED")
             ):
-                model = find_next_word_in_string(job["spec"]["config"]["entrypoint"], "--model")
-                data = find_next_word_in_string(job["spec"]["config"]["entrypoint"], "--data_path")
+                model = find_next_word_in_string(
+                    job["spec"]["config"]["entrypoint"], "--model"
+                )
+                data = find_next_word_in_string(
+                    job["spec"]["config"]["entrypoint"], "--data_path"
+                )
                 table.add_row(job["id"], job["name"], model, data, job["status"])
 
     if table.row_count <= 15:
