@@ -1,6 +1,6 @@
 # Standard modules
 import os
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List
 from datetime import datetime
 
 # Third-party modules
@@ -12,16 +12,22 @@ from rich.panel import Panel
 import yaml
 
 # Product modules
-from .utils import print_to_string
 from .client import get_garb, send_request
-from .datamodels.datamodels.api import InferenceDeploymentIn, InferenceDeploymentStatus
+from .datamodels.datamodels.api import (
+    InferenceDeploymentIn,
+    InferenceDeploymentStatus,
+    InferenceDeploymentAutoscalingConfig,
+)
+from .utils import CategorizedMutuallyExclusiveOption, PatchedCommand
+
+DEFAULT_AUTOSCALING_CONFIG = InferenceDeploymentAutoscalingConfig()
 
 
 def get_deployment(inf_id: str) -> Dict[str, Any]:
     console = Console()
 
     with console.status(
-            f"[bold green]Getting deployment with inf_id {inf_id}..."
+        f"[bold green]Getting deployment with inf_id {inf_id}..."
     ) as status:
 
         resp = send_request("GET", f"/sg_inf/{inf_id}")
@@ -95,16 +101,39 @@ def print_inference_deployments(
     for col in col_names:
         table.add_column(col)
 
-    provisioning = sorted([d for d in deployments if d['status'] == InferenceDeploymentStatus.PROVISIONING],
-                          key=lambda dep: datetime.strptime(dep["timestamp"], '%Y-%m-%d %H:%M:%S.%f'), reverse=True)
-    active = sorted([d for d in deployments if d['status'] == InferenceDeploymentStatus.ACTIVE],
-                    key=lambda dep: datetime.strptime(dep["timestamp"], '%Y-%m-%d %H:%M:%S.%f'), reverse=True)
-    inactive = sorted([d for d in deployments if d['status'] == InferenceDeploymentStatus.INACTIVE],
-                      key=lambda dep: datetime.strptime(dep["timestamp"], '%Y-%m-%d %H:%M:%S.%f'), reverse=True)
-    deleted = sorted([d for d in deployments if
-                      d['status'] not in [InferenceDeploymentStatus.PROVISIONING, InferenceDeploymentStatus.ACTIVE,
-                                          InferenceDeploymentStatus.INACTIVE]],
-                     key=lambda dep: datetime.strptime(dep["timestamp"], '%Y-%m-%d %H:%M:%S.%f'), reverse=True)
+    provisioning = sorted(
+        [
+            d
+            for d in deployments
+            if d["status"] == InferenceDeploymentStatus.PROVISIONING
+        ],
+        key=lambda dep: datetime.strptime(dep["timestamp"], "%Y-%m-%d %H:%M:%S.%f"),
+        reverse=True,
+    )
+    active = sorted(
+        [d for d in deployments if d["status"] == InferenceDeploymentStatus.ACTIVE],
+        key=lambda dep: datetime.strptime(dep["timestamp"], "%Y-%m-%d %H:%M:%S.%f"),
+        reverse=True,
+    )
+    inactive = sorted(
+        [d for d in deployments if d["status"] == InferenceDeploymentStatus.INACTIVE],
+        key=lambda dep: datetime.strptime(dep["timestamp"], "%Y-%m-%d %H:%M:%S.%f"),
+        reverse=True,
+    )
+    deleted = sorted(
+        [
+            d
+            for d in deployments
+            if d["status"]
+            not in [
+                InferenceDeploymentStatus.PROVISIONING,
+                InferenceDeploymentStatus.ACTIVE,
+                InferenceDeploymentStatus.INACTIVE,
+            ]
+        ],
+        key=lambda dep: datetime.strptime(dep["timestamp"], "%Y-%m-%d %H:%M:%S.%f"),
+        reverse=True,
+    )
 
     deployments = provisioning + active + inactive + deleted
 
@@ -146,12 +175,16 @@ def infer():
     pass
 
 
-def create_inf_dep(inf_dep_req_data: InferenceDeploymentIn, quiet: bool = False, force: bool = False):
+def create_inf_dep(
+    inf_dep_req_data: InferenceDeploymentIn, quiet: bool = False, force: bool = False
+):
 
     console = Console()
 
     with console.status("[bold green]Creating new deployment...") as status:
-        resp = send_request("POST", "/sg_inf/create", data=inf_dep_req_data.model_dump(mode="json"))
+        resp = send_request(
+            "POST", "/sg_inf/create", data=inf_dep_req_data.model_dump(mode="json")
+        )
         inf_id = ""
 
     if resp.status_code == 200:
@@ -191,31 +224,250 @@ def create_inf_dep(inf_dep_req_data: InferenceDeploymentIn, quiet: bool = False,
         )
 
 
-@infer.command("create")
-@click.option("--model", type=click.STRING, required=True, help="Model to use")
-@click.option("--max_price_per_hour", type=click.INT, required=True, help="The maximum price you are willing to spend per hour")
-@click.option("--allow_spot_instances", type=click.BOOL, required=False, default=False, help="Use spot instances")
-@click.option("--name", type=click.STRING, required=True, help="Deployment name to use")
-@click.option("--hf_token", type=click.STRING, required=False, default=None, help="Hugging Face token to use")
-@click.option("--logs_store", type=click.STRING, required=False, help="Logs store to use")
-@click.option("--enable_speedup_shared", type=click.BOOL, required=False, default=False, help="Enable fast auto scaling using shared capacity")
-@click.option("--type", type=click.Choice(["embedding", "llm"]), required=True, help="Inference deployment type to use")
-@click.option("--min_workers", type=click.INT, required=False, default=0, help="The minimum number of workers to scale down to")
+@infer.command(
+    "create",
+    cls=PatchedCommand,
+    context_settings=dict(max_content_width=150),
+)
+# ******************************* COMMON OPTIONS *******************************
+@click.option(
+    "--name", type=click.STRING, required=True, help="Deployment name to use."
+)
+@click.option("--model", type=click.STRING, required=True, help="Model to use.")
+@click.option(
+    "--base_model", type=click.STRING, required=False, help="Base model to use."
+)
+@click.option(
+    "--inf_type",
+    type=click.Choice(["embedding", "llm"]),
+    required=True,
+    help="Inference deployment type to use.",
+)
+@click.option(
+    "--hf_token",
+    type=click.STRING,
+    required=False,
+    help="Hugging Face token to use.",
+)
+@click.option(
+    "--allow_spot_instances",
+    is_flag=True,
+    required=False,
+    help="Use spot instances.",
+)
+@click.option(
+    "--logs_store", type=click.STRING, required=False, help="Logs store to use."
+)
+@click.option(
+    "--max_price_per_hour",
+    type=click.INT,
+    required=True,
+    help="The maximum price you are willing to spend per hour.",
+)
+# ******************************* CLOUD PROVIDER OPTIONS *******************************
+@click.option(
+    "--cloud_providers",
+    cls=CategorizedMutuallyExclusiveOption,
+    type=click.STRING,
+    required=False,
+    multiple=True,
+    help="Specify cloud provider in upper case. "
+    + click.style("Example: AWS.", italic=True),
+    category="Cloud options",
+)
+@click.option(
+    "--cloud_regions",
+    cls=CategorizedMutuallyExclusiveOption,
+    type=click.STRING,
+    required=False,
+    multiple=True,
+    help="Specify cloud region in following style <PROVIDER>:<region>. "
+    + click.style("Example: AWS:us-east-1.", italic=True),
+    category="Cloud options",
+)
+# ******************************* AUTO-SCALING OPTIONS *******************************
+@click.option(
+    "--enable_speedup_shared",
+    cls=CategorizedMutuallyExclusiveOption,
+    is_flag=True,
+    required=False,
+    help="Enable fast auto scaling using shared capacity.",
+    category="Auto-scaling options",
+)
+@click.option(
+    "--scale_to_zero",
+    cls=CategorizedMutuallyExclusiveOption,
+    is_flag=True,
+    required=False,
+    help="Enable scaling to zero.",
+    category="Auto-scaling options",
+)
+@click.option(
+    "--lower_allowed_latency_sec",
+    cls=CategorizedMutuallyExclusiveOption,
+    type=click.FLOAT,
+    required=False,
+    default=DEFAULT_AUTOSCALING_CONFIG.lower_allowed_latency_sec,
+    help="Lower allowed latency in seconds to use.",
+    category="Auto-scaling options",
+    show_default=True,
+)
+@click.option(
+    "--upper_allowed_latency_sec",
+    cls=CategorizedMutuallyExclusiveOption,
+    type=click.FLOAT,
+    required=False,
+    default=DEFAULT_AUTOSCALING_CONFIG.upper_allowed_latency_sec,
+    help="Upper allowed latency in seconds to use.",
+    category="Auto-scaling options",
+    show_default=True,
+)
+@click.option(
+    "--scale_to_zero_timeout_sec",
+    cls=CategorizedMutuallyExclusiveOption,
+    type=click.FLOAT,
+    required=False,
+    default=DEFAULT_AUTOSCALING_CONFIG.scale_to_zero_timeout_sec,
+    help="Scaling down to zero timeout in seconds to use.",
+    category="Auto-scaling options",
+    show_default=True,
+)
+@click.option(
+    "--scaling_down_timeout_sec",
+    cls=CategorizedMutuallyExclusiveOption,
+    type=click.FLOAT,
+    required=False,
+    default=DEFAULT_AUTOSCALING_CONFIG.scaling_down_timeout_sec,
+    help="Scaling down timeout in seconds to use.",
+    category="Auto-scaling options",
+    show_default=True,
+)
+@click.option(
+    "--scaling_up_timeout_sec",
+    cls=CategorizedMutuallyExclusiveOption,
+    type=click.FLOAT,
+    required=False,
+    default=DEFAULT_AUTOSCALING_CONFIG.scaling_up_timeout_sec,
+    help="Scaling up timeout in seconds to use.",
+    category="Auto-scaling options",
+    show_default=True,
+)
+@click.option(
+    "--scale_down_time_window_sec",
+    cls=CategorizedMutuallyExclusiveOption,
+    type=click.FLOAT,
+    required=False,
+    default=DEFAULT_AUTOSCALING_CONFIG.scale_down_time_window_sec,
+    help="Scaling down time window in seconds to use.",
+    category="Auto-scaling options",
+    show_default=True,
+)
+@click.option(
+    "--scale_up_time_window_sec",
+    cls=CategorizedMutuallyExclusiveOption,
+    type=click.FLOAT,
+    required=False,
+    default=DEFAULT_AUTOSCALING_CONFIG.scale_up_time_window_sec,
+    help="Scaling up time window in seconds to use.",
+    category="Auto-scaling options",
+    show_default=True,
+)
+# ******************************* MIN THROUGHPUT CONFIGURATION OPTIONS *******************************
+@click.option(
+    "--min_throughput_rate",
+    cls=CategorizedMutuallyExclusiveOption,
+    type=click.INT,
+    required=False,
+    help="The minimum throughput rate you need to.",
+    mutually_exclusive=[
+        "min_workers",
+        "use_same_gpus_when_scaling",
+        "initial_workers_gpu_num",
+        "initial_workers_gpu_type",
+        "instance_types",
+    ],
+    category="Options responsible for minimum throughput configuration",
+)
+# ******************************* OPTIMAL WORKER CONFIGURATION OPTIONS *******************************
+@click.option(
+    "--min_workers",
+    cls=CategorizedMutuallyExclusiveOption,
+    type=click.INT,
+    required=False,
+    default=0,
+    help="The minimum number of workers to scale down to.",
+    category="Options responsible for optimal worker configuration",
+    mutually_exclusive=["min_throughput_rate"],
+    show_default=True,
+)
+@click.option(
+    "--use_same_gpus_when_scaling",
+    cls=CategorizedMutuallyExclusiveOption,
+    is_flag=True,
+    required=False,
+    help="Enable to use same GPU type when scaling up.",
+    category="Options responsible for optimal worker configuration",
+    mutually_exclusive=["min_throughput_rate"],
+)
+@click.option(
+    "--initial_workers_gpu_num",
+    cls=CategorizedMutuallyExclusiveOption,
+    type=click.INT,
+    required=False,
+    help="Initial number of GPUs per worker.",
+    category="Options responsible for optimal worker configuration",
+    mutually_exclusive=["min_throughput_rate"],
+)
+@click.option(
+    "--initial_workers_gpu_type",
+    cls=CategorizedMutuallyExclusiveOption,
+    type=click.INT,
+    required=False,
+    help="Initial number of GPUs per worker.",
+    category="Options responsible for optimal worker configuration",
+    mutually_exclusive=["min_throughput_rate"],
+)
+@click.option(
+    "--instance_types",
+    cls=CategorizedMutuallyExclusiveOption,
+    type=click.INT,
+    required=False,
+    multiple=True,
+    help="Provide space-separated list of instance types.",
+    category="Options responsible for optimal worker configuration",
+    mutually_exclusive=[
+        "min_throughput_rate",
+        "initial_workers_gpu_type",
+        "initial_workers_gpu_num",
+        "use_same_gpus_when_scaling",
+    ],
+)
+# ******************************* API GATEWAY OPTIONS *******************************
+@click.option(
+    "--api_gateway_cloud",
+    cls=CategorizedMutuallyExclusiveOption,
+    type=click.STRING,
+    required=False,
+    default="AWS",
+    help="Specify API gateway cloud provider in upper case. "
+    + click.style("Example: AWS.", italic=True),
+    category="API gateway options",
+    show_default=True,
+)
+@click.option(
+    "--api_gateway_region",
+    cls=CategorizedMutuallyExclusiveOption,
+    type=click.STRING,
+    required=False,
+    default="us-east-1",
+    help="Specify API gateway cloud provider region. "
+    + click.style("Example: us-east-1.", italic=True),
+    category="API gateway options",
+    show_default=True,
+)
 @click.option("-f", "--force", is_flag=True)
 @click.option("-q", "--quiet", is_flag=True)
-def create_impl(
-        model,
-        max_price_per_hour,
-        allow_spot_instances,
-        name,
-        hf_token,
-        logs_store,
-        enable_speedup_shared,
-        type,
-        min_workers,
-        force,
-        quiet,
-):
+def create_impl(**inference_kwargs):
     """
     Create an inference deployment
     """
@@ -225,9 +477,12 @@ def create_impl(
 
     # Check if there is already a deployment with the same model
     similar_deployments = list(
-        map(lambda x: x["id"], filter(lambda x: x["model"] == model, deployments))
+        map(
+            lambda x: x["id"],
+            filter(lambda x: x["model"] == inference_kwargs["model"], deployments),
+        )
     )
-    if similar_deployments and not force:
+    if similar_deployments and not inference_kwargs["force"]:
         # If exists, Warn the user
         if not click.confirm(
             click.style(
@@ -238,8 +493,7 @@ def create_impl(
             exit()
 
     # Make request to P-API
-            
-    if not type in [ "llm", "embedding" ]:
+    if not inference_kwargs["inf_type"] in ["llm", "embedding"]:
         click.echo(
             click.style(
                 f"\nType value must be one of [ llm , embedding ]",
@@ -249,26 +503,62 @@ def create_impl(
         )
         exit()
 
+    if inference_kwargs["cloud_providers"]:
+        cloud_providers_dict = dict.fromkeys(inference_kwargs["cloud_providers"], [])
+        for region in inference_kwargs["cloud_regions"]:
+            cloud, region = region.split(":")
+            cloud_providers_dict[cloud].append(region)
+        cloud_providers = [
+            {"name": key, "regions": value}
+            for key, value in cloud_providers_dict.items()
+        ]
+    else:
+        cloud_providers = []
+
     data = {
-        "name": name,
-        "model": model,
-        "inf_type": type,
-        "hf_token": hf_token,
-        "allow_spot_instances": allow_spot_instances,
-        "logs_store": logs_store,
-        "cloud_providers": [],
+        "name": inference_kwargs["name"],
+        "model": inference_kwargs["model"],
+        "inf_type": inference_kwargs["inf_type"],
+        "hf_token": inference_kwargs["hf_token"],
+        "allow_spot_instances": inference_kwargs["allow_spot_instances"],
+        "logs_store": inference_kwargs["logs_store"],
+        "cloud_providers": cloud_providers,
         "initial_worker_config": {
-            "min_workers": min_workers,
+            "min_workers": inference_kwargs["min_workers"],
+            "initial_workers_gpu": inference_kwargs["initial_workers_gpu_type"],
+            "initial_workers_gpu_num": inference_kwargs["initial_workers_gpu_num"],
+            "use_same_gpus_when_scaling": inference_kwargs[
+                "use_same_gpus_when_scaling"
+            ],
+            "instance_types": inference_kwargs["instance_types"],
         },
         "autoscaling_config": {
-            "enable_speedup_shared": enable_speedup_shared,
+            "enable_speedup_shared": inference_kwargs["enable_speedup_shared"],
+            "scale_to_zero": inference_kwargs["scale_to_zero"],
+            "scale_up_time_window_sec": inference_kwargs["scale_up_time_window_sec"],
+            "scale_down_time_window_sec": inference_kwargs[
+                "scale_down_time_window_sec"
+            ],
+            "upper_allowed_latency_sec": inference_kwargs["upper_allowed_latency_sec"],
+            "lower_allowed_latency_sec": inference_kwargs["lower_allowed_latency_sec"],
+            "scaling_up_timeout_sec": inference_kwargs["scaling_up_timeout_sec"],
+            "scaling_down_timeout_sec": inference_kwargs["scaling_down_timeout_sec"],
+            "scale_to_zero_timeout_sec": inference_kwargs["scale_to_zero_timeout_sec"],
         },
-        "max_price_per_hour": max_price_per_hour,
+        "gateway_config": {
+            "name": inference_kwargs["api_gateway_cloud"],
+            "region": inference_kwargs["api_gateway_region"],
+        },
+        "max_price_per_hour": inference_kwargs["max_price_per_hour"],
+        "min_throughput_rate": inference_kwargs["min_throughput_rate"],
     }
 
     inf_dep_req_data = InferenceDeploymentIn(**data)
-
-    create_inf_dep(inf_dep_req_data, quiet=quiet, force=force)
+    create_inf_dep(
+        inf_dep_req_data,
+        quiet=inference_kwargs["quiet"],
+        force=inference_kwargs["force"],
+    )
 
 
 @infer.command("launch")
@@ -302,15 +592,13 @@ def launch_impl(config_file, force, quiet):
     except Exception as e:
         click.echo(click.style(f"Validation Error: {e}", fg="red"), err=True)
         exit()
-    
-    create_inf_dep(inf_dep_create_req, quiet, force)
 
+    create_inf_dep(inf_dep_create_req, quiet, force)
 
 
 @infer.command("start")
 @click.option("--inf_id", type=click.STRING, required=True)
-
-@click.option('-f', '--force', is_flag=True)
+@click.option("-f", "--force", is_flag=True)
 @click.option("-q", "--quiet", is_flag=True)
 def start_impl(inf_id, force, quiet):
     """
@@ -322,7 +610,7 @@ def start_impl(inf_id, force, quiet):
         console = Console()
 
         with console.status(
-                f"[bold green]Getting deployment with inf_id {inf_id}..."
+            f"[bold green]Getting deployment with inf_id {inf_id}..."
         ) as status:
 
             resp = send_request("GET", f"/sg_inf/{inf_id}/gpu_nodes_ips")
@@ -361,10 +649,10 @@ def start_impl(inf_id, force, quiet):
         if (len(resp_json) > 0) and not force:
             # If there are already existing GPU nodes, Warn the user
             if not click.confirm(
-                    click.style(
-                        f"Deployment {inf_id} already running with {len(resp_json)} GPU nodes. Do you want to continue scaling up?",
-                        fg="yellow",
-                    )
+                click.style(
+                    f"Deployment {inf_id} already running with {len(resp_json)} GPU nodes. Do you want to continue scaling up?",
+                    fg="yellow",
+                )
             ):
                 exit()
 
@@ -376,7 +664,7 @@ def start_impl(inf_id, force, quiet):
     with console.status(
         f"[bold green]Scaling deployment with inf_id {inf_id}..."
     ) as status:
-        
+
         resp = send_request("POST", f"/sg_inf/{inf_id}/scale/up")
 
     if resp.status_code == 200:
@@ -400,9 +688,7 @@ def start_impl(inf_id, force, quiet):
         try:
             resp_data = resp.json()
             click.echo(
-                click.style(
-                    f"\nCould not scale up deployment: {resp_data}", fg="red"
-                ),
+                click.style(f"\nCould not scale up deployment: {resp_data}", fg="red"),
                 err=True,
             )
         except Exception as e:
@@ -414,7 +700,7 @@ def start_impl(inf_id, force, quiet):
     # Exit if quiet was passed
     if not quiet:
         print_inference_deployments(
-            [get_deployment(inf_id)], 
+            [get_deployment(inf_id)],
             table_title="Deployment started!",
         )
 
@@ -430,7 +716,7 @@ def delete_impl(inf_id, quiet):
     console = Console()
 
     with console.status(
-            f"[bold green]Deleting deployment with inf_id {inf_id}..."
+        f"[bold green]Deleting deployment with inf_id {inf_id}..."
     ) as status:
 
         resp = send_request("DELETE", f"/sg_inf/{inf_id}")
@@ -465,10 +751,10 @@ def delete_impl(inf_id, quiet):
                 click.style(f"\nCould not delete deployment", fg="red"), err=True
             )
         exit()
-    
+
     if not quiet:
         print_inference_deployments(
-            [get_deployment(inf_id)], 
+            [get_deployment(inf_id)],
             table_title="Deployment deleted!",
         )
 
@@ -506,9 +792,19 @@ def view_impl(inf_id):
         f"[orange_red1]Status[/orange_red1] : [yellow]{inf_dep['status']}[/yellow]\n"
     )
     markdown_content += f"[orange_red1]Cost[/orange_red1] : [yellow]$ {round(inf_dep['current_price_per_hour'], 3)}[/yellow]\n"
-    markdown_content += f"[orange_red1]Model[/orange_red1] : [yellow]{inf_dep['model']}[/yellow]\n"
-    markdown_content += f"[orange_red1]Endpoint[/orange_red1] : [yellow]{inf_dep['link']}/inference[/yellow]\n"
+    markdown_content += (
+        f"[orange_red1]Model[/orange_red1] : [yellow]{inf_dep['model']}[/yellow]\n"
+    )
+
+    url = inf_dep.get("link", "")
+    if url:
+        if inf_dep["inf_type"] == "llm":
+            url += "/inference"
+        else:
+            url += "inference/embed"
+    markdown_content += (
+        f"[orange_red1]Endpoint[/orange_red1] : [yellow]{url}[/yellow]\n"
+    )
     markdown_content += f"[orange_red1]APIKey[/orange_red1] : [yellow]{get_garb('AUTH_ENDPOINT_KEY_' + inf_id)}[/yellow]\n"
 
-
     console.print(Panel(markdown_content))
