@@ -18,6 +18,7 @@ from rich.table import Table
 from rich.text import Text
 import threading
 from typing import Dict
+from gettext import gettext as _
 
 
 from .datamodels.datamodels import CodeCopy, CodeCopyType
@@ -307,7 +308,7 @@ def show_job_live_logs(job_id: str):
 
         if non_dapp_trials and non_dapp_trials[0]["status"] == "RUNNING":
 
-            logs_url = f"https://proxy-prod.storch-api.com/logs/{job_id}/{non_dapp_trials[0]['trial_id']}/get-last-lines?num=100&mtime={{}}"
+            logs_url = f"https://proxy-prod.scalegen.ai/logs/{job_id}/{non_dapp_trials[0]['trial_id']}/get-last-lines?num=100&mtime={{}}"
             counter = 0
 
             log_resp = requests.get(logs_url.format(round(time.time() * 1000)))
@@ -385,3 +386,49 @@ def print_to_string(*args, **kwargs):
     contents = output.getvalue()
     output.close()
     return contents
+
+
+class CategorizedMutuallyExclusiveOption(click.Option):
+    def __init__(self, *args, **kwargs):
+        self.mutually_exclusive = set(kwargs.pop("mutually_exclusive", []))
+        self.category = kwargs.pop("category", "Common options")
+        help = kwargs.get("help", "")
+        if self.mutually_exclusive:
+            ex_str = ", ".join(self.mutually_exclusive)
+            kwargs["help"] = help + click.style(
+                " NOTE: This argument is mutually exclusive with"
+                " arguments: (" + ex_str + ").",
+                italic=True,
+            )
+        super(CategorizedMutuallyExclusiveOption, self).__init__(*args, **kwargs)
+
+    def handle_parse_result(self, ctx, opts, args):
+        if self.mutually_exclusive.intersection(opts) and self.name in opts:
+            raise click.UsageError(
+                "Illegal usage: `{}` is mutually exclusive with "
+                "arguments `{}`.".format(self.name, ", ".join(self.mutually_exclusive))
+            )
+        return super(CategorizedMutuallyExclusiveOption, self).handle_parse_result(
+            ctx, opts, args
+        )
+
+
+class PatchedCommand(click.Command):
+    def format_options(
+        self, ctx: click.Context, formatter: click.HelpFormatter
+    ) -> None:
+        """Writes all the options into the formatter if they exist."""
+        categories = {}
+        for param in self.get_params(ctx):
+            rv = param.get_help_record(ctx)
+            if hasattr(param, "category") and rv is not None:
+                categories.setdefault(param.category, []).append(rv)
+            elif not hasattr(param, "category") and rv is not None:
+                categories.setdefault("Common options", []).append(rv)
+
+        if categories:
+
+            with formatter.section(_("Options")):
+                for group_name, opts in categories.items():
+                    with formatter.section(group_name):
+                        formatter.write_dl(opts, col_max=40, col_spacing=4)
